\name{mtm.lag1}
\alias{mtm.lag1}
\title{
Fit a (lag 1) Marginal Transition Model
}
\description{
Fit a lag-1 marginal transition model for longitudinal binary outcome data.
}
\usage{
mtm.lag1(marginal, trans1, id, beta=NULL, alpha1=NULL, offset=NULL, data = sys.frame(sys.parent()), tol = 1e-4)
}
\arguments{
\item{marginal}{
a symbolic description of the model to be fit that generally takes the form \code{y ~ x}.  Further details of model specification are provided below.
}
\item{trans1}{
covariates used to estimate the dependence of \code{y(t)} on \code{y(t-1)}. In general, \code{trans1} has the form \code{ ~ z1} where \code{z1} may or may not be a subset of covariates \code{x}.
}
\item{id}{
a vector that identifies the clusters which correspond to the binary response vector given by \code{y}.
}
\item{beta}{
initial parameter estimate(s) of how the covariates \code{x(t)} influence the average response \code{y(t)}. The estimates may be provided by the user and number of estimates provided in \code{beta} should correspond to the number of covariates in \code{x}, including an intercept.
}
\item{alpha1}{
initial estimate(s) of how the dependence of \code{y(t)} on \code{y(t-1)} varies as a function of covariate(s) \code{z1}.  The number of estimates may be provided by the user and the number of estimates in \code{alpha1} should correspond to the number of covariates in \code{z1} used to assess the serial dependence in the outcome measure.
}
\item{offset}{
this can be used to specify an a priori known component to be included in the linear predictor during fitting
}

\item{tol}{
tolerance is a measure used in the numerical calculations to determine whether or not convergence of the point estimates has occurred.  The default is 1e-4.
}

\item{data}{
an optional data frame containing the variables in the model. If not found in \code{data}, the variables are taken from \code{environment(marginal)}, typically the environment from which \code{mtm.lag1} is called.
}}

\value{
Returns an object of class \code{mtm.lag1}. The function \code{print.mtm1} may used to obtain and print a summary of the results.  See below for an example.
}
\section{DETAILS}{

\code{mtm.lag1} assumes that the longitudinal measurements of \code{y} and \code{x} are collected at equally spaced intervals, though each of the \code{N} clusters or individuals need not have measurements at every interval.  \code{y} is the longitudinal (binary) response vector measured on clusters or individuals specified by \code{id}. 

The \code{marginal} model is specified symbolically as a formula.  A typical marginal model has the form \code{y ~ x}.  The covariates \code{x} are a series of terms separated by \code{+} which specify the marginal linear predictor for \code{y}.  The parameter(s) \code{beta} denote the marginal dependence of \code{y(t)} on covariates \code{x(t)}  The user may provide initial estimate(s) for \code{beta}.     

The parameter \code{alpha1} determines how the dependence of \code{y(t)} on \code{y(t-1)} varies as a function of covariates \code{z1(t)}.  The transitional model statement (\code{trans1}) has the form \code{ ~ z1}.  The covariates \code{z1} are generally a subset of \code{x}, possibly just an intercept.

All formulas have an implied intercept term.  To remove this include \code{-1} on the right-hand side of the formula statement.  See \code{\link{formula}} for more details. 

}
\references{
P. Heagerty (2002),
Marginalized transition models and likelihood inference for longitudinal categorical data.
\emph{Biometrics,}
\bold{58}, 342-51.

A. Azzalini (1994),
Logistic regression for autocorrelated data with application to repeated measures.
\emph{Biometrika,}
\bold{81}, 767-75 (correction: 1997. \bold{84}, 989).
}
\seealso{
\code{\link{mtm.lag2}}}
\examples{
#
## Data for this example may be found in the dataset 'madras.rda'.
#
	data(madras)
	attach(madras)
#
## lag-1 MTM model call -- Model 1 of Heagerty (2002):
#
	model1 <- mtm.lag1(marginal=y ~ month + age + gender + monthXage + monthXgender, 
			   trans1 = ~ 1, id=id, beta=NULL, alpha1=NULL, data=madras)
	print.mtm1(model1)
}
\keyword{}
