\name{mtm.lag2}
\alias{mtm.lag2}
\title{
Fit a (lag 2) Marginal Transition Model
}
\description{
Fit a lag-2 marginal transition model for longitudinal binary outcome data.
}
\usage{
mtm.lag2(marginal, trans1, trans2, id, beta=NULL, alpha1=NULL, alpha2=NULL, tol = 1e-4, iter = 50, data=sys.frame(sys.parent()))
}
\arguments{
\item{marginal}{
a symbolic description of the model to be fit that generally takes the form \code{y ~ x}.  Further details of model specification are provided below.
}
\item{trans1}{
covariates used to estimate the dependence of \code{y(t)} on \code{y(t-1)}. The model specification of the \code{z1} is a subset of covariates \code{x}.
}
\item{trans2}{
covariates used to estimate the dependence of \code{y(t)} on \code{y(t-2)}. In general, \code{z2} is a subset of covariates \code{x}.
}
\item{id}{
a vector that identifies the clusters which correspond to the binary response vector given by \code{y}.
}
\item{beta}{
initial parameter estimate(s) optionally provided by the user of how the covariates \code{x(t)} influence the average response \code{y(t)}. The number of estimates provided in \code{beta} should correspond to the number of covariates in \code{x}, including an intercept.
}
\item{alpha1}{
initial estimate(s) optionally provided by the user of how the dependence of \code{y(t)} on \code{y(t-1)} varies as a function of covariate(s) \code{z1}.  The number of estimates provided in \code{alpha1} should correspond to the number of covariates in \code{z1} used to assess the serial dependence in the outcome measure.
}
\item{alpha2}{
initial estimate(s) optionally provided by the user of how the dependence of \code{y(t)} on \code{y(t-2)} varies as a function of covariate(s) \code{z2}.  The number of estimates provided in \code{alpha2} should correspond to the number of covariates in \code{z2} used to assess the serial dependence in the outcome measure.
}
\item{tol}{
tolerance is a measure used in the numerical calculations to determine whether or not convergence of the point estimates has occurred.  The default is 1e-4.
}
\item{iter}{
number of iterations to obtain convergence of estimates with the limits specified by \code{tol}. The default is \code{50} iterations.
}

\item{data}{
an optional data frame containing the variables in the model. If not found in \code{data}, the variables are taken from \code{environment(formula)}, typically the environment from which \code{mtm.lag2} is called.
}}

\value{
Returns an object of class \code{mtm.lag2}. The function \code{print.mtm2} is used to obtain and print a summary of the results.  See below for an example.
}
\section{DETAILS}{

\code{mtm.lag2} assumes that the longitudinal measurements of \code{y} and \code{x} are collected at equally spaced intervals, though each of the \code{N} clusters or individuals need not have measurements at every interval.  \code{y} is the longitudinal (binary) response vector measured on clusters or individuals specified by \code{id}.  

The \code{marginal} model is specified symbolically as a formula.  A typical model has the form \code{y ~ x}  The covariates \code{x} are a series of terms separated by \code{+} which specify the marginal linear predictor for \code{y}.  The parameter(s) \code{beta} denote the marginal dependence of \code{y(t)} on covariates \code{x(t)}  The user may provide initial estimate(s) for \code{beta}.  

The transitional model statement (\code{trans1}) has the form \code{ ~ z1} where \code{trans1}.  The parameter(s) \code{alpha1} determine how the dependence of \code{y(t)} on \code{y(t-1)} varies as a function of covariates \code{z1(t-1)}.  The covariates \code{z1} are generally a subset of \code{x}, possibly just an intercept.  An initial estimate of \code{alpha1} may be provided by the user.  

The transitional model statement (\code{trans2}) has the form \code{ ~ z2} where \code{trans2}.  The parameter(s) \code{alpha2} determine how the dependence of \code{y(t)} on \code{y(t-2)} varies as a function of covariates \code{z2(t-2)}.  The covariates \code{z2} are generally a subset of \code{x}, possibly just an intercept.  An initial estimate of \code{alpha2} may be provided by the user. 

All formulas have an implied intercept term.  To remove this include \code{-1} on the right-hand side of the formula statement.  See \code{\link{formula}} for more details.

}
\references{
P. Heagerty (2002),
Marginalized transition models and likelihood inference for longitudinal categorical data.
\emph{Biometrics,}
\bold{58}, 342-51.

A. Azzalini (1994),
Logistic regression for autocorrelated data with application to repeated measures.
\emph{Biometrika,}
\bold{81}, 767-75 (correction: 1997. \bold{84}, 989).
}
\seealso{
\code{\link{mtm.lag1}}}
\examples{
#
## Data for this example may be found in the dataset 'madras.rda'.
#
	data(madras)	
	attach(madras)
#
## lag-2 MTM model call -- Model 5 of Heagerty (2002):
#
	model2 <- mtm.lag2(marginal = y ~ month + age + gender + monthXage + monthXgender, 
			 trans1 = ~ initial + month,
			 trans2 = ~ 1, 
			 id=id, beta=NULL, alpha1=NULL, alpha2=NULL, data=madras)
	print.mtm2(model2)
}
\keyword{}
